@@ -17,7 +17,7 @@
 
 package Git::Hooks::CheckRewrite;
 {
-  $Git::Hooks::CheckRewrite::VERSION = '0.046';
+  $Git::Hooks::CheckRewrite::VERSION = '0.047';
 }
 # ABSTRACT: Git::Hooks plugin for checking against unsafe rewrites
 
@@ -110,10 +110,9 @@ branch(es):
 
     $branches
 
-Consider amending or undoing it:
+Consider amending it again:
 
-        git commit --amend      # to amend it
-        git reset --soft HEAD^  # to undo it
+    git commit --amend      # to amend it
 
 EOF
         return 0;
@@ -177,13 +176,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Git::Hooks::CheckRewrite - Git::Hooks plugin for checking against unsafe rewrites
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
@@ -265,7 +266,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2014 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
