@@ -1,6 +1,6 @@
 package Git::More;
 {
-  $Git::More::VERSION = '0.046';
+  $Git::More::VERSION = '0.047';
 }
 # ABSTRACT: A Git extension with some goodies for hook developers.
 
@@ -69,7 +69,7 @@ sub _compatibilize_config {
 
     foreach my $var (qw/admin userenv/) {
         next if exists $config->{githooks}{$var};
-        foreach my $plugin (qw/checkacls checkjira/) {
+        foreach my $plugin (grep {exists $config->{$_}} qw/checkacls checkjira/) {
             if (exists $config->{$plugin}{$var}) {
                 $config->{githooks}{$var} = $config->{$plugin}{$var};
                 next;
@@ -455,13 +455,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Git::More - A Git extension with some goodies for hook developers.
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -803,7 +805,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2014 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
